@@ -11,6 +11,7 @@
 #include <config.h>
 #include <string.h>
 #include "x.h"
+#include "util.h"
 #include "global.h"
 #include "dir.h"
 #include "command.h"
@@ -26,6 +27,7 @@
 #include "dir.h"
 #include "dialog.h"
 #include "setup.h"
+#include "fileopctx.h"
 #include "gdesktop.h"
 #include "gdnd.h"
 #include "gtkdtree.h"
@@ -37,7 +39,6 @@
 #include "gtkflist.h"
 #include "../vfs/vfs.h"
 #include <gdk/gdkprivate.h>
-#include <glib.h>
 
 /* Whether to display the tree view on the left */
 int tree_panel_visible = -1;
@@ -242,7 +243,7 @@ panel_fill_panel_icons (WPanel *panel)
 
 	gnome_icon_list_freeze (icons);
 	gnome_icon_list_clear (icons);
-
+#if 0
 	/*
 	 * HACK_BEGIN:
 	 *    Temporary hack for pre-gnome-libs-1.0.10
@@ -254,8 +255,8 @@ panel_fill_panel_icons (WPanel *panel)
 	/*
 	 * HACK_END:
 	 */
-	 
-	for (i = 0; i < top; i++){
+#endif
+	for (i = 0; i < top; i++) {
 		file_entry *fe = &panel->dir.list [i];
 		int p;
 		
@@ -341,16 +342,13 @@ x_select_item (WPanel *panel)
 	do_file_mark (panel, panel->selected, 1);
 	display_mini_info (panel);
 
-	if (panel->list_type == list_icons){
+	if (panel->list_type == list_icons) {
 		GnomeIconList *list = ILIST_FROM_SW (panel->icons);
 
 		gnome_icon_list_select_icon (list, panel->selected);
-
-		if (list->icon_list){
-			if (GTK_WIDGET (list)->allocation.x != -1)
-				if (gnome_icon_list_icon_is_visible (list, panel->selected) != GTK_VISIBILITY_FULL)
-					gnome_icon_list_moveto (list, panel->selected, 0.5);
-		}
+		if (GTK_WIDGET (list)->allocation.x != -1)
+			if (gnome_icon_list_icon_is_visible (list, panel->selected) != GTK_VISIBILITY_FULL)
+				gnome_icon_list_moveto (list, panel->selected, 0.5);
 	} else {
 		GtkCList *clist = CLIST_FROM_SW (panel->list);
 
@@ -443,7 +441,7 @@ panel_file_list_configure_contents (GtkWidget *sw, WPanel *panel, int main_width
 	usable_pixels = width - extra_pixels;
 	total_columns = usable_pixels / char_width;
 	extra_columns = total_columns - used_columns;
-	if (extra_columns > 0) {
+	if (extra_columns > 0 && expandables > 0) {
 		expand_space  = extra_columns / expandables;
 		extra_space   = extra_columns % expandables;
 	} else
@@ -1621,164 +1619,6 @@ panel_create_cwd (Dlg_head *h, WPanel *panel, void **entry)
 	return GTK_WIDGET (in->widget.wdata);
 }
 
-/* FIXME: for now, this list is hardcoded.  We want a way to let the user configure it. */
-
-static struct filter_item {
-	char *text;
-	char *glob;
-} filter_items [] = {
-	{ N_("All files"),
-	  "*" },
-	{ N_("Archives and compressed files"),
-	  "*.(tar|gz|tgz|taz|zip|lha|zoo|pak|sit|arc|arj|rar|huf|lzh)" },
-	{ N_("RPM/DEB files"),
-	  "*.(rpm|deb)" },
-	{ N_("Text/Document files"),
-	  "*.(txt|tex|doc|rtf)" },
-	{ N_("HTML and SGML files"),
-	  "*.(html|htm|sgml|sgm)" },
-	{ N_("Postscript and PDF files"),
-	  "*.(ps|pdf)" },
-	{ N_("Spreadsheet files"),
-	  "*.(xls|wks|wk1)" },
-	{ N_("Image files"),
-	  "*.(png|jpg|jpeg|xcf|gif|tif|tiff|xbm|xpm|pbm|pgm|ppm|tga|rgb|iff|lbm|ilbm|"
-	  "bmp|pcx|pic|pict|psd|gbr|pat|ico|fig|cgm|rle|fits)" },
-	{ N_("Video/animation files"),
-	  "*.(mpg|mpeg|mov|avi|fli|flc|flh|flx|dl)" },
-	{ N_("Audio files"),
-	  "*.(au|wav|mp3|snd|mod|s3m|ra)" },
-	{ N_("C program files"),
-	  "*.[ch]" },
-	{ N_("C++ program files"),
-	  "*.(cc|C|cpp|cxx|h|H)" },
-	{ N_("Objective-C program files"),
-	  "*.[mh]" },
-	{ N_("Scheme program files"),
-	  "*.scm" },
-	{ N_("Assembler program files"),
-	  "*.(s|S|asm)" },
-	{ N_("Misc. program files"),
-	  "*.(awk|sed|lex|l|y|sh|idl|pl|py|am|in|f|el|bas|pas|java|sl|p|m4|tcl|pov)" },
-	{ N_("Font files"),
-	  "*.(pfa|pfb|afm|ttf|fon|pcf|pcf.gz|spd)" }
-};
-
-static GtkWidget *filter_menu;
-
-static void
-filter_item_select (GtkWidget *widget, gpointer data)
-{
-	/* FIXME: the hintbar resizes horribly and screws the panel */
-#if 0
-	struct filter_item *fi = gtk_object_get_user_data (GTK_OBJECT (widget));
-
-	set_hintbar (easy_patterns ? fi->glob : fi->regexp);
-#endif
-}
-
-static void
-filter_item_deselect (GtkWidget *widget, gpointer data)
-{
-/*	set_hintbar (""); */
-}
-
-static void
-filter_item_activate (GtkWidget *widget, gpointer data)
-{
-	struct filter_item *fi = gtk_object_get_user_data (GTK_OBJECT (widget));
-	WPanel *panel = data;
-	char *pattern;
-
-	if (easy_patterns)
-		pattern = g_strdup (fi->glob);
-	else {
-		/* This is sort of a hack to force convert_pattern() to actually convert the thing */
-
-		easy_patterns = 1;
-		pattern = convert_pattern (fi->glob, match_file, 0);
-		easy_patterns = 0;
-	}
-
-	set_panel_filter_to (panel, pattern);
-}
-
-static void
-build_filter_menu (WPanel *panel, GtkWidget *button)
-{
-	GtkWidget *item;
-	int i;
-
-	if (filter_menu)
-		return;
-
-	/* FIXME: the filter menu is global, and it is never destroyed */
-
-	filter_menu = gtk_menu_new ();
-
-	gtk_object_set_user_data (GTK_OBJECT (filter_menu), button);
-
-	for (i = 0; i < ELEMENTS (filter_items); i++) {
-		item = gtk_menu_item_new_with_label (_(filter_items[i].text));
-		gtk_object_set_user_data (GTK_OBJECT (item), &filter_items[i]);
-
-		gtk_signal_connect (GTK_OBJECT (item), "select",
-				    (GtkSignalFunc) filter_item_select,
-				    panel);
-		gtk_signal_connect (GTK_OBJECT (item), "deselect",
-				    (GtkSignalFunc) filter_item_deselect,
-				    panel);
-		gtk_signal_connect (GTK_OBJECT (item), "activate",
-				    (GtkSignalFunc) filter_item_activate,
-				    panel);
-
-		gtk_widget_show (item);
-		gtk_menu_append (GTK_MENU (filter_menu), item);
-	}
-}
-
-static void
-position_filter_popup (GtkMenu *menu, gint *x, gint *y, gpointer data)
-{
-	int screen_width, screen_height;
-	GtkWidget *wmenu = GTK_WIDGET (menu);
-	GtkWidget *button = GTK_WIDGET (data);
-
-	/* This code is mostly ripped off from gtkmenu.c - Federico */
-
-	screen_width = gdk_screen_width ();
-	screen_height = gdk_screen_height ();
-
-	gdk_window_get_origin (button->window, x, y);
-
-	*y += button->allocation.height;
-
-	if ((*x + wmenu->requisition.width) > screen_width)
-		*x -= (*x + wmenu->requisition.width) - screen_width;
-
-	if ((*y + wmenu->requisition.height) > screen_height)
-		*y -= (*y + wmenu->requisition.height) - screen_height;
-
-	if (*y < 0)
-		*y = 0;
-}
-
-static void
-show_filter_popup (GtkWidget *button, gpointer data)
-{
-	WPanel *panel;
-
-	panel = data;
-
-	build_filter_menu (panel, button);
-
-	gtk_menu_popup (GTK_MENU (filter_menu), NULL, NULL,
-			position_filter_popup,
-			button,
-			1,
-			GDK_CURRENT_TIME);
-}
-
 void
 display_mini_info (WPanel *panel)
 {
@@ -2204,6 +2044,55 @@ panel_tree_drag_leave (GtkWidget *widget, GdkDragContext *context, guint time, g
 	panel->drag_tree_row = -1;
 }
 
+#if CONTEXT_MENU_ON_TREE
+static void
+tree_do_op (GtkWidget *tree, WPanel *panel, int operation)
+{
+}
+
+static void
+tree_copy_cmd (GtkWidget *tree, WPanel *panel)
+{
+	tree_do_op (tree, panel, OP_COPY);
+}
+
+static void
+tree_del_cmd (GtkWidget *tree, WPanel *panel)
+{
+	tree_do_op (tree, panel, OP_DELETE);
+}
+
+static void
+tree_ren_cmd (GtkWidget *tree, WPanel *panel)
+{
+	tree_do_op (tree, panel, OP_MOVE);
+}
+
+static GnomeUIInfo tree_popup_items[] = {
+	GNOMEUIINFO_ITEM_STOCK(N_("_Copy..."), N_("Copy directory"), tree_copy_cmd, GNOME_STOCK_PIXMAP_COPY),
+	GNOMEUIINFO_ITEM_STOCK(N_("_Delete..."), N_("Delete directory"), tree_del_cmd, GNOME_STOCK_PIXMAP_TRASH),
+        GNOMEUIINFO_ITEM_NONE(N_("_Move..."), N_("Rename or move directory"), tree_ren_cmd),
+
+	GNOMEUIINFO_END
+};
+
+static void
+panel_tree_button_press (GtkWidget *widget, GdkEventButton *event, WPanel *panel)
+{
+	GtkWidget *popup;
+	
+	if (event->type != GDK_BUTTON_PRESS)
+		return;
+	
+	if (event->button != 3)
+		return;
+
+	popup = gnome_popup_menu_new (tree_popup_items);
+	gnome_popup_menu_do_popup_modal (popup, NULL, NULL, event, panel);
+	gtk_widget_destroy (popup);
+}
+#endif
+
 /**
  * panel_create_tree_view:
  *
@@ -2257,6 +2146,12 @@ panel_create_tree_view (WPanel *panel)
 	gtk_signal_connect (GTK_OBJECT (tree), "drag_data_received",
 			    GTK_SIGNAL_FUNC (panel_tree_drag_data_received), panel);
 
+#ifdef CONTEXT_MENU_ON_TREE
+	/* Context sensitive menu */
+	gtk_signal_connect_after (GTK_OBJECT (tree), "button_press_event",
+				  GTK_SIGNAL_FUNC (panel_tree_button_press), panel);
+	gtk_clist_set_button_actions (GTK_CLIST (tree), 2, GTK_BUTTON_SELECTS);
+#endif
 	return tree;
 }
 
@@ -2373,7 +2268,7 @@ tree_size_allocate (GtkWidget *widget, GtkAllocation *allocation, WPanel *panel)
 void
 x_create_panel (Dlg_head *h, widget_data parent, WPanel *panel)
 {
-	GtkWidget *status_line, *filter, *vbox, *ministatus_box;
+	GtkWidget *status_line, *vbox, *ministatus_box;
 	GtkWidget *cwd;
 	GtkWidget *dock;
 	GnomeUIBuilderData uibdata;
